@@ -56,20 +56,25 @@ class ClientIdAuthAttributes:
 
       if os.path.exists(resourcePath):
          try:
-            fpResource = open(resourcePath,'r')
+            fpResource = open(resourcePath,'rb')
             try:
                eof = False
                while not eof:
-                  record = fpResource.readline()
-                  if record != "":
-                     if   record.startswith('session_token '):
-                        self.sessionAttributes['sessionToken'] = record.split()[1]
-                     elif record.startswith('sessionid '):
-                        self.sessionAttributes['sessionId'] = record.split()[1]
-                     elif record.startswith('cache_hosts '):
-                        self.sessionAttributes['cacheHosts'] = record.split()[1]
+                  encodedRecord = fpResource.readline()
+                  try:
+                     record = encodedRecord.decode('utf-8')
+                  except UnicodeDecodeError:
+                     pass
                   else:
-                     eof = True
+                     if record != "":
+                        if   record.startswith('session_token '):
+                           self.sessionAttributes['sessionToken'] = record.split()[1]
+                        elif record.startswith('sessionid '):
+                           self.sessionAttributes['sessionId'] = record.split()[1]
+                        elif record.startswith('cache_hosts '):
+                           self.sessionAttributes['cacheHosts'] = record.split()[1]
+                     else:
+                        eof = True
             except:
                pass
             finally:
