@@ -25,6 +25,8 @@
 #
 # HUBzero is a registered trademark of The Regents of the University of California.
 #
+__version__ = '3.11.1'
+
 import sys
 import os
 import json
@@ -49,22 +51,15 @@ from hubzero.submit.Probe              import Probe
 from hubzero.submit.ProbeQueue         import ProbeQueue
 
 class ProbeLauncher:
-   CONFIGURATIONDIRECTORY = os.path.join(os.sep,'etc','submit')
-   CONFIGURATIONFILE      = 'submit-probe.conf'
-   PROBELOGLOCATION       = "log"
-   PROBELOGFILE           = "probeLauncher.log"
-
    def __init__(self,
                 probeRoot,
-                probeLogLocation=PROBELOGLOCATION,
-                probeLogFile=PROBELOGFILE,
-                configurationDirectory=CONFIGURATIONDIRECTORY):
-      logDirectory = os.path.join(probeRoot,probeLogLocation)
-      self.openLogger(logDirectory,probeLogFile)
-      self.logger = logging.getLogger(__name__)
+                configurationDirectory,
+                configurationFilename):
+      self.logger = self.logger = logging.getLogger(__name__)
 
+      self.version             = __version__
       self.probeRoot           = probeRoot
-      self.configFilePath      = os.path.join(configurationDirectory,self.CONFIGURATIONFILE)
+      self.configFilePath      = os.path.join(configurationDirectory,configurationFilename)
       self.remoteProbeMonitors = []
       self.configData          = {}
 
@@ -90,6 +85,8 @@ remoteVenue=@@{REMOTEVENUE}
 probeId=@@{PROBEID}
 probeProgram=@@{PROBEPROGRAM}
 nCores=@@{NCORES}
+nGpus=@@{NGPUS}
+memory=@@{MEMORY}
 wallTime=@@{WALLTIME}
 inputs="@@{INPUTS}"
 preSubmitCommands="@@{PRESUBMITCOMMANDS}"
@@ -97,17 +94,28 @@ postSubmitCommands="@@{POSTSUBMITCOMMANDS}"
 
 coreArg=
 if [ ${nCores} -gt -1 ] ; then
-   coreArg="-nCpus ${nCores}"
+   coreArg="--nCpus ${nCores}"
 fi
 
-wallTimeArg="-wallTime 10"
+gpuArg=
+if [ ${nGpus} -gt -1 ] ; then
+   gpuArg="--nGpus ${nGpus}"
+fi
+
+memoryArg=
+if [ ${memory} -gt -1 ] ; then
+   memoryArg="--memory ${memory}"
+fi
+
+wallTimeArg="--wallTime 10"
 if [ -n "${wallTime}" ] ; then
    wallTimeArg="-w ${wallTime}"
 fi
+
 x509SubmitProxyArg=
-if [ -f ~/.globus/probe.proxy ] ; then
-   x509SubmitProxyArg="--x509SubmitProxy ~/.globus/probe.proxy"
-fi
+#if [ -f ~/.globus/probe.proxy ] ; then
+#   x509SubmitProxyArg="--x509SubmitProxy ~/.globus/probe.proxy"
+#fi
 
 #echo gridProbeRoot=${gridProbeRoot}
 #echo probeDirectory=${probeDirectory}
@@ -115,6 +123,8 @@ fi
 #echo probeId=${probeId}
 #echo probeProgram=${probeProgram}
 #echo nCores=${nCores}
+#echo nGpus=${nGpus}
+#echo memory=${memory}
 #echo wallTime=${wallTime}
 #echo inputs=${inputs}
 #echo preSubmitCommands=${preSubmitCommands}
@@ -191,6 +201,8 @@ EOF
 
       ${SUBMITPATH} --venue ${remoteVenue} \
                     ${coreArg} \
+                    ${gpuArg} \
+                    ${memoryArg} \
                     ${wallTimeArg} \
                     ${x509SubmitProxyArg} \
                     --disableProbeCheck \
@@ -370,41 +382,6 @@ exit ${exitStatus}
       self.sigGEN_handler(signal,frame)
 
 
-   def openLogger(self,
-                  logDirectory,
-                  probeLogFile):
-      class EmptyFilter(logging.Filter):
-         """
-         This is a filter which rejects empty messages
-
-         """
-
-         def filter(self,record):
-            if record.getMessage() == "":
-               emptyRecord = True
-            else:
-               emptyRecord = False
-
-            return(not emptyRecord)
-
-      APPLICATIONLOGGER = logging.getLogger('')
-      APPLICATIONLOGGER.setLevel(logging.DEBUG)
-
-      if not os.path.isdir(logDirectory):
-         os.makedirs(logDirectory)
-
-      probeLogPath = os.path.join(logDirectory,probeLogFile)
-      logHandler = logging.FileHandler(probeLogPath)
-      self.fdLogFile = logHandler.stream.fileno()
-
-      emptyFilter = EmptyFilter()
-      logHandler.addFilter(emptyFilter)
-
-      logFormatter = logging.Formatter('%(asctime)s %(message)s','[%a %b %d %H:%M:%S %Y]')
-      logHandler.setFormatter(logFormatter)
-      APPLICATIONLOGGER.addHandler(logHandler)
-
-
    def configure(self):
       configured = False
 
@@ -435,7 +412,7 @@ exit ${exitStatus}
                                            'probeSitesFile':"probeSites.dat",
                                            'probeSiteShell':"./probesite.sh",
                                            'submitPath':"/usr/bin/submit",
-                                           'pegasusVersion':"4.5.2",
+                                           'pegasusVersion':"4.8.1",
                                            'remoteProbeMonitorHosts':[]
                                           }
                   elif inProbeSection:
@@ -506,31 +483,6 @@ exit ${exitStatus}
       return(configured)
 
 
-   def daemonize(self):
-      if self.fdLogFile != sys.stdout.fileno():
-         try:
-            devnull = open("/dev/null",'r')
-            try:
-               os.dup2(devnull.fileno(),sys.stdin.fileno())
-               os.dup2(self.fdLogFile,sys.stdout.fileno())
-               os.dup2(self.fdLogFile,sys.stderr.fileno())
-            except OSError:
-               self.logger.log(logging.ERROR,getLogMessage("file descriptor dup failed"))
-         except (IOError,OSError):
-            self.logger.log(logging.ERROR,getLogMessage("%s could not be opened" % ("/dev/null")))
-
-      if os.fork() != 0:
-         os.wait()
-         sys.exit(0)
-      else:
-         os.setsid()
-         pid = os.fork()
-         if pid != 0:
-            sys.exit(0)
-
-      time.sleep(2)
-
-
    def loadProbeSitesInfo(self):
       oldProbeSites = copy.copy(self.probeSites)
       del self.probeSites
@@ -552,6 +504,8 @@ exit ${exitStatus}
                   siteName = sitePattern.match(record).group(2)
                   self.probeSites[siteName] = {'probeProgram':'./probegridsite.sh', \
                                                'nCores':-1, \
+                                               'nGpus':-1, \
+                                               'memory':-1, \
                                                'maximumTimeToProbeCompletion':-1, \
                                                'wallTime':10, \
                                                'inputs':[], \
@@ -922,6 +876,8 @@ exit ${exitStatus}
                   substitutions["PROBEID"]            = "%09d" % (probe.id)
                   substitutions["PROBEPROGRAM"]       = self.probeSites[probe.destination]['probeProgram']
                   substitutions["NCORES"]             = self.probeSites[probe.destination]['nCores']
+                  substitutions["NGPUS"]              = self.probeSites[probe.destination]['nGpus']
+                  substitutions["MEMORY"]             = self.probeSites[probe.destination]['memory']
                   substitutions["WALLTIME"]           = self.probeSites[probe.destination]['wallTime']
                   substitutions["INPUTS"]             = inputs
                   substitutions["PRESUBMITCOMMANDS"]  = preSubmitCommands
